@@ -65,18 +65,18 @@ module.exports = function (app) {
 
     app.use(function (req, res, next) {
 
-     //   req.r = app.nylon.req.r;
-     //   console.log(app.nylon.req.r)
+        //   req.r = app.nylon.req.r;
+        //   console.log(app.nylon.req.r)
         //req.logger = app.nylon.logger;
 
-      Object.assign(req,app.nylon.req);
-      Object.assign(res,app.nylon.res);
-       //  console.log(req);
+        Object.assign(req, app.nylon.req);
+        Object.assign(res, app.nylon.res);
+        //  console.log(req);
 
-       
 
-        // res.header("Access-Control-Allow-Origin", "*");
-        // res.header("Access-Control-Allow-Headers", "Origin, X-Custom-Header, X-Requested-With, Content-Type, Accept, X-APP-ID, X-APP-KEY, Authorization");
+
+        res.header("Access-Control-Allow-Origin", "*");
+        res.header("Access-Control-Allow-Headers", "Origin, X-Custom-Header, X-Requested-With, Content-Type, Accept, X-APP-ID, X-APP-KEY, Authorization, token");
         next();
     });
 
@@ -86,8 +86,8 @@ module.exports = function (app) {
     fscan.scan(work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, nylon_path, "/api", work_dir, route_dir, routes, function (err, app) {
 
-           // app.use(express.static(work_dir + '/public'));
-           // app.use('/nylon', express.static(nylon_path + '/lib/public'));
+            // app.use(express.static(work_dir + '/public'));
+            // app.use('/nylon', express.static(nylon_path + '/lib/public'));
             // app.use(function (req, res, next) {
             //     var ref = req.headers["referer"];
             //     console.log(ref);
